==> haskell-http-client-0.7.17-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.17
visibility:           public
id:                   http-client-0.7.17-GjKLViTNtmdDUQUFfydSDc
key:                  http-client-0.7.17-GjKLViTNtmdDUQUFfydSDc
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  04190a954e58b0b48deb00ed97b6bd82
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.17-GjKLViTNtmdDUQUFfydSDc
depends:
    array-0.5.4.0 async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q base-4.17.2.1
    base64-bytestring-1.2.1.0-4q5KLdrxF6BHAwlK9Y3XXj
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-BBd0FN3VG9pHwba5nfbZ8v containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm deepseq-1.4.8.0
    exceptions-0.10.5 filepath-1.4.2.2 ghc-prim-0.9.1
    http-types-0.12.4-ELP3cONQaOf7BJAjzf0skh
    iproute-1.7.15-7hVuJTzQFAED0zMLQy38xi
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO
    network-uri-2.6.4.2-EDr74t9h07L15oCNeDNFfl
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv stm-2.5.1.0
    streaming-commons-0.2.2.6-I3OsSmUhnzkHM5bhkWdxLd text-2.0.2
    time-1.12.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.7.17-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.17
visibility:           public
id:                   http-client-0.7.17-GO4dubzcf4ODgZYG2FtYuG
key:                  http-client-0.7.17-GO4dubzcf4ODgZYG2FtYuG
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  3b24258677c1faed110ec93077bc9fa1
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.17-GO4dubzcf4ODgZYG2FtYuG
depends:
    array-0.5.4.0 async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q base-4.17.2.1
    base64-bytestring-1.2.1.0-4q5KLdrxF6BHAwlK9Y3XXj
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-BBd0FN3VG9pHwba5nfbZ8v containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm deepseq-1.4.8.0
    exceptions-0.10.5 filepath-1.4.2.2 ghc-prim-0.9.1
    http-types-0.12.4-DgYrgAx3aYriPsC9m33YD
    iproute-1.7.15-7hVuJTzQFAED0zMLQy38xi
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO
    network-uri-2.6.4.2-EDr74t9h07L15oCNeDNFfl
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv stm-2.5.1.0
    streaming-commons-0.2.2.6-I3OsSmUhnzkHM5bhkWdxLd text-2.0.2
    time-1.12.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
